==> 2.2.3.tar.gz: lib/XWidgets/XTextFormField/XTextFormFieldWithLabel.dart <==
part of xwidgetbase;

class XTextFormFieldWithLabel extends StatelessWidget {
  final String? label;
  final IconData? icon;
  final TextAlignVertical? textAlignVertical;
  final ValueChanged<String>? onChanged;
  final Function()? onPressed;
  final FocusNode? focusNode;
  final String? initialValue;
  final TextInputType? keyboardType;
  final TextEditingController? controller;
  final Function(String)? onFieldSubmitted;
  final String? hintText;
  final EdgeInsets? marginContainerText;
  VoidCallback? onEditingComplete;
  List<TextInputFormatter>? inputFormatters;
  InputDecoration? decoration = const InputDecoration();
  FormFieldValidator<String>? validator;
  AutovalidateMode? autovalidateMode;
  bool? autovalidate = false;
  GestureTapCallback? onTap;
  bool? expands = false;
  int? maxLines = 1;
  final int? minLines;
  TextAlign? textAlign = TextAlign.start;
  Alignment? alignmentLabel = Alignment.center;
  final Alignment? alignment;
  CrossAxisAlignment? crossAxisAlignment = CrossAxisAlignment.center;
  final Color? colorBorder;
  final bool? readOnlyFormField;
  final TextStyle? textStyle;
  final TextStyle? hintStyle;
  final int? flexLabelContainer;
  final int? flexTextContainer;
  final TextStyle? labelStyle;
  final int? maxLenght;

  XTextFormFieldWithLabel({
    this.crossAxisAlignment,
    this.label = "",
    this.marginContainerText,
    this.controller,
    this.labelStyle,
    this.textStyle,
    this.hintStyle,
    this.textAlign,
    this.flexTextContainer,
    this.maxLenght,
    this.colorBorder,
    this.readOnlyFormField = false,
    this.alignment,
    this.onEditingComplete,
    this.onTap,
    this.textAlignVertical,
    this.alignmentLabel,
    this.icon,
    this.validator,
    this.autovalidateMode,
    this.onChanged,
    this.autovalidate,
    this.inputFormatters,
    this.decoration,
    this.minLines,
    this.maxLines,
    this.expands = false,
    this.onPressed,
    this.keyboardType,
    this.initialValue = "",
    this.focusNode,
    this.flexLabelContainer,
    this.onFieldSubmitted,
    this.hintText = '',
  })  : assert(maxLines == null || maxLines > 0),
        assert(expands != null),
        assert(
          !expands! || (maxLines == null && minLines == null),
          'minLines e MxLines devono essere null quando expands è true.',
        );
  @override
  Widget build(BuildContext context) {
    return Row(
      crossAxisAlignment: crossAxisAlignment ?? CrossAxisAlignment.center,
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        SizedBox(width: 5),
        Visibility(
          visible: label != "",
          child: Expanded(
            flex: flexLabelContainer ?? 1,
            child: Container(
              alignment: alignmentLabel,
              child: Text(
                label!,
                style: labelStyle ?? Theme.of(context).textTheme.caption,
              ),
            ),
          ),
        ),
        Expanded(
          flex: flexTextContainer ?? 4,
          child: Container(
            margin: marginContainerText ?? EdgeInsets.only(left: 5),
            child: readOnlyFormField == false
                ? FormField(
                    autovalidateMode: AutovalidateMode.onUserInteraction,
                    builder: (FormFieldState state) {
                      return TextFormField(
                        onEditingComplete: onEditingComplete,
                        onTap: onTap,
                        textAlign: textAlign ?? TextAlign.start,
                        controller: initialValue != null ? null : controller,
                        validator: validator,
                        autovalidateMode: autovalidateMode ?? AutovalidateMode.always,
                        maxLines: maxLines,
                        maxLength: maxLenght,
                        initialValue: controller != null ? null : initialValue,
                        onChanged: onChanged,
                        focusNode: focusNode ?? FocusNode(),
                        keyboardType: keyboardType ?? TextInputType.text,
                        inputFormatters: inputFormatters ?? [],
                        onFieldSubmitted: onFieldSubmitted!,
                        decoration: InputDecoration(
                          border: UnderlineInputBorder(borderSide: BorderSide(color: colorBorder ?? XColors.xcolor_ForegroundLight, width: 4)),
                          hintText: hintText,
                          hintStyle: hintStyle,
                        ),
                      );
                    },
                  )
                : Text(
                    initialValue ?? "",
                    style: textStyle,
                    textAlign: textAlign ?? TextAlign.start,
                    maxLines: maxLines,
                  ),
          ),
        ),
      ],
    );
  }
}

==> 11.3.0.tar.gz: lib/XWidgets/XTextFormField/XTextFormFieldWithLabel.dart <==
part of xwidgetbase;

class XTextFormFieldWithLabel extends StatelessWidget {
  final String? label;
  final IconData? icon;
  final TextAlignVertical? textAlignVertical;
  final ValueChanged<String>? onChanged;
  final Function()? onPressed;
  final FocusNode? focusNode;
  final String? initialValue;
  final TextInputType? keyboardType;
  final TextEditingController? controller;
  final Function(String)? onFieldSubmitted;
  final String? hintText;
  final EdgeInsets? marginContainerText;
  VoidCallback? onEditingComplete;
  List<TextInputFormatter>? inputFormatters;
  InputDecoration? decoration = const InputDecoration();
  FormFieldValidator<String>? validator;
  AutovalidateMode? autovalidateMode;
  bool? autovalidate = false;
  GestureTapCallback? onTap;
  bool? expands = false;
  int? maxLines = 1;
  final int? minLines;
  TextAlign? textAlign = TextAlign.start;
  Alignment? alignmentLabel = Alignment.center;
  final Alignment? alignment;
  CrossAxisAlignment? crossAxisAlignment = CrossAxisAlignment.center;
  final Color? colorBorder;
  final bool? readOnlyFormField;
  final TextStyle? textStyle;
  final TextStyle? hintStyle;
  final int? flexLabelContainer;
  final int? flexTextContainer;
  final TextStyle? labelStyle;
  final int? maxLenght;

  XTextFormFieldWithLabel({
    this.crossAxisAlignment,
    this.label = "",
    this.marginContainerText,
    this.controller,
    this.labelStyle,
    this.textStyle,
    this.hintStyle,
    this.textAlign,
    this.flexTextContainer,
    this.maxLenght,
    this.colorBorder,
    this.readOnlyFormField = false,
    this.alignment,
    this.onEditingComplete,
    this.onTap,
    this.textAlignVertical,
    this.alignmentLabel,
    this.icon,
    this.validator,
    this.autovalidateMode,
    this.onChanged,
    this.autovalidate,
    this.inputFormatters,
    this.decoration,
    this.minLines,
    this.maxLines,
    this.expands = false,
    this.onPressed,
    this.keyboardType,
    this.initialValue = "",
    this.focusNode,
    this.flexLabelContainer,
    this.onFieldSubmitted,
    this.hintText = '',
  })  : assert(maxLines == null || maxLines > 0),
        assert(expands != null),
        assert(
          !expands! || (maxLines == null && minLines == null),
          'minLines e MxLines devono essere null quando expands è true.',
        );
  @override
  Widget build(BuildContext context) {
    return Row(
      crossAxisAlignment: crossAxisAlignment ?? CrossAxisAlignment.center,
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        SizedBox(width: 5),
        Visibility(
          visible: label != "",
          child: Expanded(
            flex: flexLabelContainer ?? 1,
            child: Container(
              alignment: alignmentLabel,
              child: Text(
                label!,
                style: labelStyle ?? Theme.of(context).textTheme.caption,
              ),
            ),
          ),
        ),
        Expanded(
          flex: flexTextContainer ?? 4,
          child: Container(
            margin: marginContainerText ?? EdgeInsets.only(left: 5),
            child: readOnlyFormField == false
                ? FormField(
                    autovalidateMode: AutovalidateMode.onUserInteraction,
                    builder: (FormFieldState state) {
                      return TextFormField(
                        onEditingComplete: onEditingComplete,
                        onTap: onTap,
                        textAlign: textAlign ?? TextAlign.start,
                        controller: initialValue != null ? null : controller,
                        validator: validator,
                        autovalidateMode: autovalidateMode ?? AutovalidateMode.always,
                        maxLines: maxLines,
                        maxLength: maxLenght,
                        initialValue: controller != null ? null : initialValue,
                        onChanged: onChanged,
                        focusNode: focusNode ?? FocusNode(),
                        keyboardType: keyboardType ?? TextInputType.text,
                        inputFormatters: inputFormatters ?? [],
                        onFieldSubmitted: onFieldSubmitted!,
                        decoration: InputDecoration(
                          border: UnderlineInputBorder(borderSide: BorderSide(color: colorBorder ?? XColors.foregroundLight, width: 4)),
                          hintText: hintText,
                          hintStyle: hintStyle,
                        ),
                      );
                    },
                  )
                : Text(
                    initialValue ?? "",
                    style: textStyle,
                    textAlign: textAlign ?? TextAlign.start,
                    maxLines: maxLines,
                  ),
          ),
        ),
      ],
    );
  }
}
